@@ -37,7 +37,11 @@ from forms import PhotoForm
 class TagMixin(object):
     def get_context_data(self, **kwargs):
         context = super(TagMixin, self).get_context_data(**kwargs)
-        context['tags'] = Tag.objects.all()
+        if self.request.user.is_superuser:
+            context['tags'] = Tag.objects.all()
+        else:
+            tags = Tag.objects.filter(photo__status=True)
+            context['tags'] = tags.distinct()
         return context
 
 
